@@ -6,12 +6,14 @@ from tests import json
 from nose.tools import assert_equal
 
 import jmespath
+from jmespath.visitor import TreeInterpreter, Options
 
 
-TEST_DIR = os.path.join(
-    os.path.dirname(os.path.abspath(__file__)),
-    'compliance')
+TEST_DIR = os.path.dirname(os.path.abspath(__file__))
+COMPLIANCE_DIR = os.path.join(TEST_DIR, 'compliance')
+LEGACY_DIR = os.path.join(TEST_DIR, 'legacy')
 NOT_SPECIFIED = object()
+OPTIONS = Options(dict_cls=OrderedDict)
 
 
 def test_compliance():
@@ -40,6 +42,9 @@ def _walk_files():
         for root, dirnames, filenames in os.walk(TEST_DIR):
             for filename in filenames:
                 yield os.path.join(root, filename)
+        for root, dirnames, filenames in os.walk(LEGACY_DIR):
+            for filename in filenames:
+                yield os.path.join(root, filename)
 
 
 def _load_cases(full_path):
@@ -60,13 +65,14 @@ def _test_expression(given, expression, expected, filename):
         raise AssertionError(
             'jmespath expression failed to compile: "%s", error: %s"' %
             (expression, e))
-    actual = parsed.search(given)
+    actual = parsed.search(given, options=OPTIONS)
     expected_repr = json.dumps(expected, indent=4)
     actual_repr = json.dumps(actual, indent=4)
     error_msg = ("\n\n  (%s) The expression '%s' was suppose to give:\n%s\n"
                  "Instead it matched:\n%s\nparsed as:\n%s\ngiven:\n%s" % (
                      filename, expression, expected_repr,
-                     actual_repr, parsed, json.dumps(given, indent=4)))
+                     actual_repr, pformat(parsed.parsed),
+                     json.dumps(given, indent=4)))
     error_msg = error_msg.replace(r'\n', '\n')
     assert_equal(actual, expected, error_msg)
 
@@ -74,7 +80,7 @@ def _test_expression(given, expression, expected, filename):
 def _test_error_expression(given, expression, error, filename):
     import jmespath.parser
     if error not in ('syntax', 'invalid-type',
-                     'unknown-function', 'invalid-arity'):
+                     'unknown-function', 'invalid-arity', 'invalid-value'):
         raise RuntimeError("Unknown error type '%s'" % error)
     try:
         parsed = jmespath.compile(expression)
@@ -85,6 +91,6 @@ def _test_error_expression(given, expression, error, filename):
     else:
         error_msg = ("\n\n  (%s) The expression '%s' was suppose to be a "
                      "syntax error, but it successfully parsed as:\n\n%s" % (
-                         filename, expression, parsed))
+                         filename, expression, pformat(parsed.parsed)))
         error_msg = error_msg.replace(r'\n', '\n')
         raise AssertionError(error_msg)
